import { TextDatasource } from "./TextDatasource.js";
import { Credentials } from "../credentials/Credentials.js";
import { AttachmentDetails, BufferLike, DatasourceConfigurationMemory, DatasourceLoadedData, EncryptedContent, History, VaultID } from "../types.js";
/**
 * Memory datasource for temporary storage
 * @augments TextDatasource
 * @memberof module:Buttercup
 */
export declare class MemoryDatasource extends TextDatasource {
    protected _property: string;
    private _store;
    /**
     * Constructor for the datasource
     * @param credentials The credentials instance with which to
     *  use to configure the datasource
     */
    constructor(credentials: Credentials);
    /**
     * Ensure attachment paths exist
     * @memberof MemoryDatasource
     * @protected
     */
    _ensureAttachmentsPaths(vaultID: VaultID): Promise<void>;
    /**
     * Get attachment buffer
     * - Loads the attachment contents into a buffer
     * @param vaultID The ID of the vault
     * @param attachmentID The ID of the attachment
     * @memberof MemoryDatasource
     */
    getAttachment(vaultID: VaultID, attachmentID: string): Promise<BufferLike>;
    /**
     * Get the datasource configuration
     * @memberof MemoryDatasource
     */
    getConfiguration(): DatasourceConfigurationMemory;
    /**
     * Load from a global property
     * @param credentials The credentials for decryption
     * @returns A promise resolving with vault history
     * @memberof MemoryDatasource
     */
    load(credentials: Credentials): Promise<DatasourceLoadedData>;
    /**
     * Put encrypted attachment data
     * @param vaultID The ID of the vault
     * @param attachmentID The ID of the attachment
     * @param buffer The attachment data
     * @param details Attachment details
     * @memberof MemoryDatasource
     */
    putAttachment(vaultID: VaultID, attachmentID: string, buffer: BufferLike, details: AttachmentDetails): Promise<void>;
    /**
     * Remove an attachment
     * @param vaultID The ID of the vault
     * @param attachmentID The ID of the attachment
     * @memberof MemoryDatasource
     */
    removeAttachment(vaultID: VaultID, attachmentID: string): Promise<void>;
    /**
     * Save vault history memory
     * @param history The vault history to save
     * @param credentials The credentials to save with
     * @returns A promise that resolves when saving is complete
     * @memberof MemoryDatasource
     */
    save(history: History, credentials: Credentials): Promise<EncryptedContent>;
    /**
     * Whether or not the datasource supports attachments
     * @memberof MemoryDatasource
     */
    supportsAttachments(): boolean;
}
