import { Group } from "../core/Group.js";
import { Vault } from "../core/Vault.js";
import { GroupFacade, GroupID, VaultFacade } from "../types.js";
export interface ConsumeVaultFacadeOptions {
    mergeMode?: boolean;
}
export interface CreateVaultFacadeOptions {
    includeTrash?: boolean;
}
export interface GetGroupEntriesFacadesOptions {
    includeTrash?: boolean;
}
export interface GetGroupsFacadesOptions {
    includeTrash?: boolean;
}
/**
 * Consume a group facade and apply the differences to a group instance
 * @param group The group instance to apply to
 * @param facade The facade to apply
 * @memberof module:Buttercup
 */
export declare function consumeGroupFacade(group: Group, facade: GroupFacade): void;
/**
 * Consume a vault facade and apply the differences to the vault
 * instance
 * @param vault The vault instance to apply to
 * @param facade The facade to apply
 * @param options Options for the consumption
 * @memberof module:Buttercup
 */
export declare function consumeVaultFacade(vault: Vault, facade: VaultFacade, options?: ConsumeVaultFacadeOptions): void;
/**
 * Create a vault facade from an Vault instance
 * @param vault A vault instance
 * @returns A vault facade
 * @memberof module:Buttercup
 */
export declare function createVaultFacade(vault: Vault, options?: CreateVaultFacadeOptions): VaultFacade;
/**
 * Create a group facade from a Group instance
 * @param group The group instance
 * @param parentID The parent ID of the group
 * @memberof module:Buttercup
 */
export declare function createGroupFacade(group: Group, parentID?: GroupID): GroupFacade;
