import { VaultFormat } from "./VaultFormat.js";
import { Vault } from "../core/Vault.js";
import { Credentials } from "../credentials/Credentials.js";
import { EntryChange, EntryID, FormatAEntry, FormatAGroup, FormatAVault, GroupID, History, PropertyKeyValueObject, VaultFormatID, VaultID } from "../types.js";
export declare class VaultFormatA extends VaultFormat {
    static encodeRaw(rawContent: History, credentials: Credentials): Promise<string>;
    /**
     * Extract shares from a history collection
     * @param {String[]} history A history collection, containing shares
     * @returns {Object} The resulting separated histories. The object will
     *  always contain a `base` property containing the non-share history.
     *  Each share detected is set on the object under its share ID - being
     *  set to an array of history lines (non-prefixed) for that share.
     */
    static extractSharesFromHistory(history: History): Object;
    static getFormatID(): VaultFormatID;
    static historiesDiffer(historyA: History, historyB: History): boolean;
    static isEncrypted(contents: string): boolean;
    static parseEncrypted(encryptedContent: string, credentials: Credentials): Promise<History>;
    static vaultFromMergedHistories(base: History, incoming: History): Vault;
    protected _history: History;
    source: FormatAVault;
    constructor(source?: FormatAVault);
    cloneEntry(entry: FormatAEntry, targetGroupID: GroupID): void;
    cloneGroup(group: FormatAGroup, targetGroupID: GroupID): void;
    createEntry(groupID: GroupID, entryID: EntryID): void;
    createGroup(parentID: GroupID, groupID: GroupID): void;
    deleteEntry(entryID: EntryID): void;
    deleteEntryAttribute(entryID: EntryID, attribute: string): void;
    deleteEntryProperty(entryID: EntryID, property: string): void;
    deleteGroup(groupID: GroupID): void;
    deleteGroupAttribute(groupID: GroupID, attribute: string): void;
    deleteVaultAttribute(attribute: string): void;
    erase(): void;
    execute(commandOrCommands: string | Array<string>): void;
    findEntryByID(id: EntryID): FormatAEntry;
    findGroupByID(id: GroupID): FormatAGroup;
    findGroupContainingEntryID(id: EntryID): FormatAGroup;
    findGroupContainingGroupID(id: GroupID): FormatAGroup;
    generateID(): void;
    getAllEntries(parentID?: GroupID): Array<FormatAEntry>;
    getAllGroups(parentID?: GroupID): Array<FormatAGroup>;
    getEntryAttributes(entrySource: FormatAEntry): PropertyKeyValueObject;
    getEntryChanges(entrySource: FormatAEntry): Array<EntryChange>;
    getEntryProperties(entrySource: FormatAEntry): PropertyKeyValueObject;
    getFormat(): any;
    getGroupAttributes(groupSource: FormatAGroup): PropertyKeyValueObject;
    getGroupTitle(groupSource: FormatAGroup): string;
    getHistory(): History;
    getItemID(itemSource: FormatAGroup | FormatAEntry): GroupID | EntryID;
    getItemParentID(itemSource: FormatAGroup | FormatAEntry): GroupID | "0";
    getVaultAttributes(): PropertyKeyValueObject;
    getVaultID(): VaultID;
    initialise(): void;
    moveEntry(entryID: EntryID, groupID: GroupID): void;
    moveGroup(groupID: GroupID, newParentID: GroupID): void;
    optimise(): void;
    setEntryAttribute(entryID: EntryID, attribute: string, value: string): void;
    setEntryProperty(entryID: EntryID, property: string, value: string): void;
    setGroupAttribute(groupID: GroupID, attribute: string, value: string): void;
    setGroupTitle(groupID: GroupID, title: string): void;
    setVaultAttribute(key: string, value: string): void;
    _executeCommand(command: string): void;
    _pad(): void;
    _processCommandParameters(commandKey: string, parameters: Array<string>): string[];
}
