import { EntryLegacyHistoryItem, EntryID, EntryPropertyType, FormatAEntry, FormatAGroup, FormatAVault, GroupID } from "../../types.js";
interface FormatACommandArgument {
    test: RegExp;
    wrap: (text: string) => string;
    encode: boolean;
}
interface FormatACommandArguments {
    [key: string]: FormatACommandArgument;
}
interface FormatACommandManifestCommand {
    s: string;
    d: boolean;
    args: Array<FormatACommandArgument>;
}
interface FormatACommandManifestCommands {
    [key: string]: FormatACommandManifestCommand;
}
export declare const COMMAND_ARGUMENT: FormatACommandArguments;
export declare const COMMAND_MANIFEST: FormatACommandManifestCommands;
export declare class InigoCommand {
    static Command: FormatACommandManifestCommands;
    static create(cmd: FormatACommandManifestCommand): InigoCommand;
    static generatePaddingCommand(): string;
    _commandKey: FormatACommandManifestCommand;
    _commandArgs: Array<string>;
    constructor(cmdKey: FormatACommandManifestCommand);
    addArgument(arg: string): this;
    generateCommand(): string;
}
/**
 * Extract command components from a string
 * @param command The command to extract from
 * @returns The separated parts
 */
export declare function extractCommandComponents(cmd: string): Array<string>;
export declare function findEntryByID(groups: Array<FormatAGroup>, id: EntryID): any;
export declare function findGroupByID(groups: any, id: any): any;
/**
 * Find a raw group that contains an entry with an ID
 * @param groups An array of raw groups
 * @param id The entry ID to search for
 * @returns The parent group of the found entry
 */
export declare function findGroupContainingEntryID(groups: Array<FormatAGroup>, id: EntryID): any;
/**
 * Find a raw group that contains a group with an ID
 * @param group The group/archive to search in
 * @param id The group ID to search for
 * @returns The parent of the located group ID
 */
export declare function findGroupContainingGroupID(group: FormatAGroup | FormatAVault, id: GroupID): any;
/**
 * @typedef {Object} EntryLegacyHistoryItem
 * @property {String} property The property/attribute name
 * @property {String} propertyType Either "property" or "attribute"
 * @property {String|null} originalValue The original value or null if it did not exist
 *  before this change
 * @property {String|null} newValue The new value or null if it was deleted
 */
/**
 * Generate a new entry history item
 * @param property The property/attribute name
 * @param propertyType Either "property" or "attribute"
 * @param originalValue The original value or null if it did not exist
 *  before this change
 * @param newValue The new value or null if it was deleted
 */
export declare function generateEntryLegacyHistoryItem(property: string, propertyType: EntryPropertyType, originalValue?: string, newValue?: string): EntryLegacyHistoryItem;
export declare function getAllEntries(source: FormatAVault, parentID?: GroupID): Array<FormatAEntry>;
export declare function getAllGroups(source: FormatAVault, parentID?: GroupID): Array<FormatAGroup>;
export declare function historyArrayToString(historyArray: Array<string>): string;
export declare function historyStringToArray(historyString: string): Array<string>;
export {};
