import { StorageInterface } from "../storage/StorageInterface.js";
import { Vault } from "../core/Vault.js";
import { EntryID, EntryType, GroupID, VaultFacade, VaultID } from "../types.js";
interface DomainScores {
    [domain: string]: number;
}
type EntryFetcher = (target: Vault | VaultFacade, memory: StorageInterface) => Promise<Array<ProcessedSearchEntry>>;
export interface ProcessedSearchEntry extends SearchResult {
    domainScores: DomainScores;
}
export interface SearcherFactory {
    (items: Array<any>): any;
}
export interface SearchResult {
    id: EntryID;
    groupID: GroupID;
    properties: {
        [property: string]: string;
    };
    entryType: EntryType;
    urls: Array<string>;
    vaultID: VaultID;
}
interface SearchScores {
    [vaultID: string]: {
        [entryID: string]: DomainScores;
    };
}
export declare class BaseSearch {
    _entries: Array<ProcessedSearchEntry>;
    _entryFetcher: EntryFetcher;
    _fuse: any;
    _memory: StorageInterface;
    _results: Array<SearchResult>;
    _searcherFactory: SearcherFactory;
    _scores: SearchScores;
    _targets: Array<Vault> | Array<VaultFacade>;
    constructor(targets: Array<Vault> | Array<VaultFacade>, entryFetcher: EntryFetcher, memory?: StorageInterface, searcherFactory?: SearcherFactory);
    /**
     * Last search results
     */
    get results(): Array<SearchResult>;
    /**
     * Increment the score of a URL in an entry
     * @param vaultID The vault ID
     * @param entryID The entry ID
     * @param url The URL to increment for
     */
    incrementScore(vaultID: VaultID, entryID: EntryID, url: string): Promise<void>;
    /**
     * Prepare the search instance by processing
     * entries
     */
    prepare(): Promise<void>;
    /**
     * Search for entries by term
     * @param term The term to search for
     * @returns An array of search results
     */
    searchByTerm(term: string): Array<SearchResult>;
    /**
     * Search for entries by URL
     * @param url The URL to search with
     * @returns An array of search results
     */
    searchByURL(url: string): Array<SearchResult>;
}
export {};
