import { StorageInterface } from "./StorageInterface.js";
/**
 * Storage interface for memory storage
 * @augments StorageInterface
 * @memberof module:Buttercup
 */
export class MemoryStorageInterface extends StorageInterface {
    constructor() {
        super(...arguments);
        this._store = {};
    }
    /**
     * Get all keys from storage
     * @returns A promise that resolves with an array of keys
     * @memberof MemoryStorageInterface
     */
    getAllKeys() {
        return Promise.resolve(Object.keys(this._store));
    }
    /**
     * Get the value of a key
     * @param name The key name
     * @returns A promise that resolves with the value
     * @memberof MemoryStorageInterface
     */
    getValue(name) {
        const value = this._store.hasOwnProperty(name) ? this._store[name] : null;
        return Promise.resolve(value);
    }
    /**
     * Remove a key
     * @param name The key name
     * @returns A promise that resolves when the removal has completed
     * @memberof MemoryStorageInterface
     */
    removeKey(name) {
        this._store[name] = undefined;
        delete this._store[name];
        return Promise.resolve();
    }
    /**
     * Set the value for a key
     * @param name The key name
     * @param value The value to set
     * @returns A promise that resolves when the value is set
     * @memberof MemoryStorageInterface
     */
    setValue(name, value) {
        this._store[name] = value;
        return Promise.resolve();
    }
}
