import { Group } from "../core/Group.js";
import { Entry } from "../core/Entry.js";
/**
 * Find entry instances by filtering with a compare function
 * @param groups The groups to check in
 * @param compareFn The callback comparison function, return true to keep and false
 *  to strip
 * @returns An array of found entries
 */
export declare function findEntriesByCheck(groups: Array<Group>, compareFn: (entry: Entry) => boolean): Array<Entry>;
/**
 * Find group instances within groups that satisfy some check
 * @param groups The groups to check within
 * @param compareFn A comparision function - return true to keep, false to strip
 * @returns An array of found groups
 */
export declare function findGroupsByCheck(groups: Array<Group>, compareFn: (group: Group) => boolean): Array<Group>;
/**
 * Get all entries within a collection of groups
 * @param groups An array of groups
 * @returns An array of entries
 */
export declare function getAllEntries(groups: Array<Group>): Array<Entry>;
