/**
 * Find entry instances by filtering with a compare function
 * @param groups The groups to check in
 * @param compareFn The callback comparison function, return true to keep and false
 *  to strip
 * @returns An array of found entries
 */
export function findEntriesByCheck(groups, compareFn) {
    let foundEntries = [], newEntries;
    groups.forEach((group) => {
        newEntries = group.getEntries().filter(compareFn);
        if (newEntries.length > 0) {
            foundEntries = foundEntries.concat(newEntries);
        }
        newEntries = findEntriesByCheck(group.getGroups(), compareFn);
        if (newEntries.length > 0) {
            foundEntries = foundEntries.concat(newEntries);
        }
    });
    return foundEntries;
}
/**
 * Find group instances within groups that satisfy some check
 * @param groups The groups to check within
 * @param compareFn A comparision function - return true to keep, false to strip
 * @returns An array of found groups
 */
export function findGroupsByCheck(groups, compareFn) {
    let foundGroups = groups.filter(compareFn);
    groups.forEach((group) => {
        const subFound = findGroupsByCheck(group.getGroups(), compareFn);
        if (subFound.length > 0) {
            foundGroups = foundGroups.concat(subFound);
        }
    });
    return foundGroups;
}
/**
 * Get all entries within a collection of groups
 * @param groups An array of groups
 * @returns An array of entries
 */
export function getAllEntries(groups) {
    return groups.reduce((current, group) => {
        const theseEntries = group.getEntries();
        const subEntries = getAllEntries(group.getGroups());
        if (theseEntries.length > 0) {
            current = current.concat(theseEntries);
        }
        if (subEntries.length > 0) {
            current = current.concat(subEntries);
        }
        return current;
    }, []);
}
