import { GoogleDriveClient } from "@buttercup/googledrive-client";
import DatasourceAuthManager from "./DatasourceAuthManager.js";
import { TextDatasource } from "./TextDatasource.js";
import { Credentials } from "../credentials/Credentials.js";
import { DatasourceConfigurationGoogleDrive } from "../types.js";
/**
 * Datasource for Google Drive archives
 * @augments TextDatasource
 * @memberof module:Buttercup
 */
export default class GoogleDriveDatasource extends TextDatasource {
    authManager: DatasourceAuthManager;
    client: GoogleDriveClient;
    fileID: string;
    token: string;
    refreshToken: string;
    /**
     * Datasource for Google Drive connections
     * @param {Credentials} credentials The credentials instance with which to
     *  configure the datasource with
     */
    constructor(credentials: Credentials);
    /**
     * Get the datasource configuration
     * @memberof GoogleDriveDatasource
     */
    getConfiguration(): DatasourceConfigurationGoogleDrive;
    /**
     * Load an archive from the datasource
     * @param {Credentials} credentials The credentials for decryption
     * @returns {Promise.<LoadedVaultData>} A promise that resolves archive history
     * @memberof GoogleDriveDatasource
     */
    load(credentials: any, hasAuthed?: boolean): any;
    /**
     * Save an archive using the datasource
     * @param {Array.<String>} history The archive history to save
     * @param {Credentials} credentials The credentials to save with
     * @returns {Promise} A promise that resolves when saving has completed
     * @memberof GoogleDriveDatasource
     */
    save(history: any, credentials: any, hasAuthed?: boolean): any;
    /**
     * Whether or not the datasource supports bypassing remote fetch operations
     * @returns {Boolean} True if content can be set to bypass fetch operations,
     *  false otherwise
     * @memberof GoogleDriveDatasource
     */
    supportsRemoteBypass(): boolean;
    /**
     * Update the OAuth2 tokens
     * @param accessToken The access token
     * @param refreshToken The refresh token, if available
     * @memberof GoogleDriveDatasource
     */
    updateTokens(accessToken: string, refreshToken?: string): void;
}
