import { Credentials } from "../credentials/Credentials.js";
import { TextDatasource } from "./TextDatasource.js";
/**
 * Convert a Credentials instance to a Datasource
 * @param credentials A Credentials instance that
 *  contains a datasource configuration
 * @throws {Error} Throws if no datasource configuration in
 *  credentials
 * @throws {Error} Throws if no type specified in datasource
 *  configuration
 * @throws {Error} Throws if no datasource found for type
 * @private
 */
export declare function credentialsToDatasource(credentials: Credentials): TextDatasource;
/**
 * Execute all datasource postprocessors
 * @param type The type of datasource
 * @param datasource The datasource instance
 * @private
 */
export declare function fireInstantiationHandlers(type: string, datasource: TextDatasource): void;
/**
 * Prepare credentials for passing to a datasource
 * (from VaultSource)
 * @param credentials
 * @private
 */
export declare function prepareDatasourceCredentials(credentials: Credentials, typeOverride?: string): Credentials;
/**
 * Register a new datasource
 * This is called internally by the built-in datasources, but should be called if a
 * custom datasource is used.
 * @param datasourceType The name (slug) of the datasource
 * @param DSClass The class for the new datasource
 * @memberof module:Buttercup
 */
export declare function registerDatasource(datasourceType: string, DSClass: any, flags?: {}): void;
interface DatasourcePostProcessorHandler {
    remove: () => void;
}
/**
 * Register a post-processor for a datasource being instantiated
 * @param {Function} callback The callback to execute with the instantiated datasource
 * @returns The result of the registration
 * @private
 */
export declare function registerDatasourcePostProcessor(callback: Function): DatasourcePostProcessorHandler;
export {};
