import { Entry } from "../core/Entry.js";
import { Group } from "../core/Group.js";
import { EntryFacade, EntryFacadeField, EntryID, EntryType, EntryPropertyValueType, GroupID, VaultFacade } from "../types.js";
export interface CreateEntryFacadeOptions {
    type?: EntryType;
}
/**
 * Process a modified entry facade
 * @param entry The entry to apply processed data on
 * @param facade The facade object
 * @memberof module:Buttercup
 */
export declare function consumeEntryFacade(entry: Entry, facade: EntryFacade): void;
/**
 * Create a data/input facade for an Entry instance
 * @param entry The Entry instance
 * @param options Options for the entry facade creation
 * @returns A newly created facade
 * @memberof module:Buttercup
 */
export declare function createEntryFacade(entry?: Entry, options?: CreateEntryFacadeOptions): EntryFacade;
/**
 * Create a new entry using an entry facade
 * @param group The parent group
 * @param facade The entry facade
 * @returns A newly created Entry
 * @memberof module:Buttercup
 */
export declare function createEntryFromFacade(group: Group, facade: EntryFacade): Entry;
/**
 * Convert an array of entry facade fields to a
 * key-value object with only properties
 * @param facadeFields Array of fields
 * @memberof module:Buttercup
 */
export declare function fieldsToProperties(facadeFields: Array<EntryFacadeField>): {
    [key: string]: string;
};
export declare function getEntryFacadePath(entryID: EntryID, facade: VaultFacade): Array<GroupID>;
/**
 * Set the value type of an entry property within a facade
 * @param facade The entry facade to modify
 * @param propertyName The property to apply a new value type to
 * @param valueType The new value type
 */
export declare function setEntryFacadePropertyValueType(facade: EntryFacade, propertyName: string, valueType: EntryPropertyValueType): void;
