import { Entry } from "../core/Entry.js";
import { EntryFacadeField, EntryFacadeFieldFormatting, EntryPropertyType, EntryPropertyValueType } from "../types.js";
export interface CreateFieldDescriptorOptions {
    formatting?: boolean | EntryFacadeFieldFormatting;
    removeable?: boolean;
    valueType?: EntryPropertyValueType;
}
/**
 * Create a descriptor for a field to be used within a facade
 * @param entry The entry instance to process or null if the initial value
 *  should be empty
 * @param title The field title
 * @param entryPropertyType The type of entry property (property/attribute)
 * @param entryPropertyName The name of the property
 * @param options The options for the field
 * @returns The field descriptor
 * @memberof module:Buttercup
 */
export declare function createFieldDescriptor(entry: Entry | null, title: string, entryPropertyType: EntryPropertyType, entryPropertyName: string, options?: CreateFieldDescriptorOptions): EntryFacadeField;
/**
 * Get a value on an entry for a specific property type
 * @param entry The entry instance
 * @param propertyType The type of entry property (property/attribute)
 * @param name The property name
 * @returns The property value
 * @throws {Error} Throws for unknown property types
 * @deprecated Not in use - To be removed
 */
export declare function getEntryValue(entry: Entry, propertyType: EntryPropertyType, name: string): string | undefined;
/**
 * Get the entry value type
 * @param entry Entry instance
 * @param propertyName The entry property name
 * @returns The entry value type (returns default "text"
 *  if entry not specified)
 */
export declare function getEntryPropertyValueType(entry: Entry | null, propertyName: string): EntryPropertyValueType;
/**
 * Check if an ID signifies a new instance and not an
 *  existing one
 * @param id The ID to check
 */
export declare function idSignifiesNew(id: string, mergeMode?: boolean): boolean;
/**
 * Set the value type attribute of an entry
 * @param entry Entry instance
 * @param propertyName The property name
 * @param valueType The value type
 */
export declare function setEntryPropertyValueType(entry: Entry, propertyName: string, valueType: EntryPropertyValueType): void;
