import EventEmitter from "eventemitter3";
import { Credentials } from "../credentials/Credentials.js";
import { Vault } from "../core/Vault.js";
import { EntryChange, EntryID, FormatAEntry, FormatAGroup, FormatAVault, FormatBEntry, FormatBGroup, FormatBVault, GroupID, History, PropertyKeyValueObject, VaultFormatID } from "../types.js";
export declare const ORPHANS_GROUP_TITLE = "Orphaned Items";
export declare class VaultFormat extends EventEmitter {
    static encodeRaw(rawContent: History, credentials: Credentials): void;
    static extractSharesFromHistory(history: History): void;
    static getFormatID(): VaultFormatID;
    static historiesDiffer(historyA: History, historyB: History): boolean;
    static isEncrypted(contents: string): void;
    static parseEncrypted(encryptedContent: string, credentials: Credentials): void;
    static vaultFromMergedHistories(local: History, incoming: History): Vault;
    protected _readOnly: boolean;
    dirty: boolean;
    source: FormatAVault | FormatBVault;
    get history(): History;
    get readOnly(): boolean;
    constructor(source: FormatAVault | FormatBVault);
    cloneEntry(entry: FormatAEntry | FormatBEntry, targetGroupID: GroupID): void;
    cloneGroup(group: FormatAGroup | FormatBGroup, targetGroupID: GroupID): void;
    createEntry(groupID: GroupID, entryID: EntryID): void;
    createGroup(parentID: GroupID, groupID: GroupID): void;
    deleteEntry(entryID: EntryID): void;
    deleteEntryAttribute(entryID: EntryID, attribute: string): void;
    deleteEntryProperty(entryID: EntryID, property: string): void;
    deleteGroup(groupID: GroupID): void;
    deleteGroupAttribute(groupID: GroupID, attribute: string): void;
    deleteVaultAttribute(attribute: string): void;
    erase(): void;
    execute(commandOrCommands: string | Array<string>): void;
    findEntryByID(id: EntryID): FormatAEntry | FormatBEntry;
    findGroupByID(id: GroupID): FormatAGroup | FormatBGroup;
    findGroupContainingEntryID(id: EntryID): FormatAGroup | FormatBGroup;
    findGroupContainingGroupID(id: GroupID): FormatAGroup | FormatBGroup;
    generateID(): void;
    getAllEntries(parentID?: GroupID): Array<FormatAEntry | FormatBEntry>;
    getAllGroups(parentID?: GroupID): Array<FormatAGroup | FormatBGroup>;
    getEntryAttributes(entrySource: FormatAEntry | FormatBEntry): PropertyKeyValueObject;
    getEntryChanges(entrySource: FormatAEntry | FormatBEntry): Array<EntryChange>;
    getEntryProperties(entrySource: FormatAEntry | FormatBEntry): PropertyKeyValueObject;
    getFormat(): any;
    getGroupAttributes(groupSource: FormatAGroup | FormatBGroup): PropertyKeyValueObject;
    getGroupTitle(groupSource: FormatAGroup | FormatBGroup): string;
    getHistory(): History;
    getItemID(itemSource: FormatAGroup | FormatAEntry | FormatBGroup | FormatBEntry): GroupID | EntryID;
    getItemParentID(itemSource: FormatAGroup | FormatAEntry | FormatBGroup | FormatBEntry): GroupID | "0";
    getVaultAttributes(): {};
    getVaultID(): void;
    initialise(): void;
    moveEntry(entryID: EntryID, groupID: GroupID): void;
    moveGroup(groupID: GroupID, newParentID: GroupID): void;
    optimise(): void;
    prepareOrphansGroup(): FormatAGroup | FormatBGroup;
    setEntryAttribute(entryID: EntryID, attribute: string, value: string): void;
    setEntryProperty(entryID: EntryID, property: string, value: string): void;
    setGroupAttribute(groupID: GroupID, attribute: string, value: string): void;
    setGroupTitle(groupID: GroupID, title: string): void;
    setVaultAttribute(key: string, value: string): void;
}
