import { Vault } from "../../core/Vault.js";
import { History } from "../../types.js";
export interface CommonRecentCommandResult {
    a: number;
    b: number;
}
export interface HistoryDifferences {
    original: History;
    secondary: History;
    common: History;
}
/**
 * Vault comparison class
 */
export default class VaultComparator {
    static calculateHistoryDifferences(historyA: History, historyB: History): HistoryDifferences;
    _vaultA: Vault;
    _vaultB: Vault;
    /**
     * Constructor for the vault comparator
     * @param originalVault The primary vault
     * @param secondaryVault The secondary vault
     */
    constructor(originalVault: Vault, secondaryVault: Vault);
    /**
     * Calculate the differences, in commands, between the two vaults
     * @returns Returns null if no common base is found, or the command
     *  differences as two arrays
     * @memberof VaultComparator
     */
    calculateDifferences(): HistoryDifferences;
    /**
     * Check if the current vaults differ
     * @returns True if the vaults are different
     * @memberof VaultComparator
     */
    vaultsDiffer(): boolean;
}
