export declare const ENCODED_STRING_PREFIX = "utf8+base64:";
/**
 * Decode a base64 string to a typed array
 * @param b64 The base64 string
 * @returns A typed array
 */
export declare function base64ToBytes(b64: string): Uint8Array;
/**
 * Encode a typed array to base64
 * @param uint8Arr The array of bytes to encode
 * @returns A base64 encoded string
 */
export declare function bytesToBase64(uint8Arr: Uint8Array): string;
/**
 * Decode a base64 string
 * @param b64 The base64 string
 * @returns The decoded string
 */
export declare function decodeBase64String(b64: string): string;
/**
 * Decode an encoded property value
 * @param value The encoded value
 * @returns The decoded value
 */
export declare function decodeStringValue(value: string): string;
/**
 * Encode a base64 string
 * @param text The raw text to encode
 * @returns A base64 encoded string
 */
export declare function encodeBase64String(text: string): string;
/**
 * Encode a raw value into safe storage form
 * Uses base64 for encoding
 * @param value The raw value to encode
 * @returns The encoded result
 */
export declare function encodeStringValue(value: string): string;
/**
 * Get a unique identifier (UUID v4)
 * @returns A unique identifier
 */
export declare function getUniqueID(): string;
/**
 * Check if a string value is encoded
 * @param text The value to check
 * @returns True if the text is encoded
 */
export declare function isEncoded(text: string): boolean;
