import { TextDatasource } from "../datasources/TextDatasource.js";
import { Credentials } from "../credentials/Credentials.js";
import { DatasourceLoadedData, EncryptedContent, History } from "../types.js";
/**
 * Local file datasource, connecting via the desktop
 * application proxy from the browser
 * @memberof module:Buttercup
 * @augments TextDatasource
 */
export default class LocalFileDatasource extends TextDatasource {
    _path: string;
    _token: string;
    client: any;
    constructor(credentials: Credentials);
    get path(): string;
    get token(): string;
    /**
     * Load archive history from the datasource
     * @param credentials The credentials for archive decryption
     * @returns A promise resolving archive history
     * @memberof LocalFileDatasource
     */
    load(credentials: Credentials): Promise<DatasourceLoadedData>;
    /**
     * Save archive contents to the WebDAV service
     * @param history Archive history
     * @param credentials The credentials for encryption
     * @returns A promise resolving when the save is complete
     * @memberof LocalFileDatasource
     */
    save(history: History, credentials: Credentials): Promise<EncryptedContent>;
    /**
     * Whether or not the datasource supports bypassing remote fetch operations
     * @returns True if content can be set to bypass fetch operations,
     *  false otherwise
     * @memberof LocalFileDatasource
     */
    supportsRemoteBypass(): boolean;
}
