import { TextDatasource } from "../datasources/TextDatasource.js";
import { Credentials } from "../credentials/Credentials.js";
import LocalStorageInterface from "./LocalStorageInterface.js";
import { DatasourceLoadedData, EncryptedContent, History } from "../types.js";
/**
 * Local Storage datasource
 * @augments TextDatasource
 * @memberof module:Buttercup
 */
export default class LocalStorageDatasource extends TextDatasource {
    _property: string;
    _storage: LocalStorageInterface;
    /**
     * Constructor for the datasource
     * @param credentials The credentials instance with which to
     *  use to configure the datasource
     */
    constructor(credentials: Credentials);
    /**
     * Load from a local-storage property
     * @param credentials The credentials for decryption
     * @returns A promise resolving with vault history
     * @memberof LocalStorageDatasource
     */
    load(credentials: Credentials): Promise<DatasourceLoadedData>;
    /**
     * Save vault history to local-storage
     * @param history The vault history to save
     * @param credentials The credentials to save with
     * @returns A promise that resolves when saving is complete
     * @memberof LocalStorageDatasource
     */
    save(history: History, credentials: Credentials): Promise<EncryptedContent>;
    /**
     * Whether or not the datasource supports attachments
     * @memberof LocalStorageDatasource
     */
    supportsAttachments(): boolean;
}
