import { StorageInterface } from "../storage/StorageInterface.js";
export declare function getStorage(): Storage;
/**
 * Interface for localStorage
 * @augments StorageInterface
 */
export default class LocalStorageInterface extends StorageInterface {
    _storage: Storage;
    get storage(): Storage;
    /**
     * Get all keys from storage
     * @returns A promise that resolves with an array of keys
     */
    getAllKeys(): Promise<string[]>;
    /**
     * Get the value of a key
     * @param name The key name
     * @returns A promise that resolves with the value
     */
    getValue(name: string): Promise<string | null>;
    /**
     * Remove a key
     * @param name The key name
     * @returns A promise that resolves when the removal has completed
     */
    removeKey(name: string): Promise<void>;
    /**
     * Set the value for a key
     * @param name The key name
     * @param value The value to set
     * @returns A promise that resolves when the value is set
     */
    setValue(name: string, value: string): Promise<void>;
}
